.. cellpy documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to cellpy's documentation!
==================================

.. include::
   readme.rst

Main description
----------------

.. toctree::
   :maxdepth: 2

   installation
   usage
   formats
   contributing
   authors
   history

Examples and tutorials
----------------------

.. toctree::
   :maxdepth: 2

   basics
   utils
   notebooks
   examples
   tips_and_tricks

Developers guide
----------------

.. toctree::
   :maxdepth: 2

   developers_guide


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
